Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6125)

Unified Diff: chrome/browser/ui/views/autofill/tooltip_icon.h

Issue 2477463003: Replace ui::AXViewState with AXNodeData and AXActionData (Closed)
Patch Set: Fix test Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/autofill/tooltip_icon.h
diff --git a/chrome/browser/ui/views/autofill/tooltip_icon.h b/chrome/browser/ui/views/autofill/tooltip_icon.h
index 9e6f16538192da3fa3e0d9c263a9cdc2fccc5bc3..482ba0b963ad498f22c1fc40723cdb2593d1cef9 100644
--- a/chrome/browser/ui/views/autofill/tooltip_icon.h
+++ b/chrome/browser/ui/views/autofill/tooltip_icon.h
@@ -36,7 +36,7 @@ class TooltipIcon : public views::ImageView,
void OnMouseEntered(const ui::MouseEvent& event) override;
void OnMouseExited(const ui::MouseEvent& event) override;
void OnGestureEvent(ui::GestureEvent* event) override;
- void GetAccessibleState(ui::AXViewState* state) override;
+ void GetAccessibleNodeData(ui::AXNodeData* node_data) override;
// views::MouseWatcherListener:
void MouseMovedOutOfHost() override;
@@ -49,7 +49,7 @@ class TooltipIcon : public views::ImageView,
}
private:
// Changes the color to reflect the hover state.
void SetDrawAsHovered(bool hovered);
// Creates and shows |bubble_|. If |bubble_| already exists, just cancels a
@@ -49,7 +49,7 @@ class TooltipIcon : public views::ImageView,
}
private:
- // Changes the color to reflect the hover state.
+ // Changes the color to reflect the hover node_data.
void SetDrawAsHovered(bool hovered);
// Creates and shows |bubble_|. If |bubble_| already exists, just cancels a

Powered by Google App Engine
This is Rietveld 408576698